package com.yiboshi.science.param.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.yiboshi.science.base.BaseDTO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 项目表DTO
 * 
 * @author lkl
 * @version 2021-08-26
 */
@Data
@EqualsAndHashCode(callSuper=true)
@ApiModel(description = "项目表DTO")
public class ComProjectBasicDTO extends BaseDTO {
    /** 项目Id */
    @ApiModelProperty(value="项目Id")
    @Length(max=36, message = "Id不能大于36")
    private String projId;
    /** 预期成果形式 */
    @ApiModelProperty(value = "预期成果形式", position = 3 )
    @Length(max=36, message = "预期成果形式不能大于36")
    private String anticipatedForms;
    /** 申请人所在单位名称 */
    @ApiModelProperty(value = "申请人所在单位名称", position = 12)
    @Length(max=200, message = "申请人所在单位名称不能大于200")
    private String appUnitName;
    /** 单位性质 */
    @ApiModelProperty(value = "单位性质", position = 1 )
    @Length(max=36, message = "单位性质不能大于36")
    private String nature;
    /** 系、所、科室 */
    @ApiModelProperty(value = "系、所、科室", position = 12)
    @Length(max=200, message = "系、所、科室不能大于200")
    private String dept;
    /** 详细地址 */
    @ApiModelProperty(value = "详细地址", position = 13)
    @Length(max=200, message = "详细地址不能大于200")
    private String address;
    /** 电话 */
    @ApiModelProperty(value = "电话", position = 14)
    @Length(max=200, message = "电话不能大于200")
    private String telephone;
    /** 手机 */
    @ApiModelProperty(value = "手机", position = 15)
    @Length(max=200, message = "手机不能大于200")
    private String mobile;
    /** 电子邮件 */
    @ApiModelProperty(value = "电子邮件", position = 16)
    @Length(max=200, message = "电子邮件不能大于200")
    private String email;
    /** 申请金额 */
    @ApiModelProperty(value = "申请金额", position = 12 )
    private BigDecimal applyMoney;
    /** 主题词 */
    @ApiModelProperty(value = "主题词", position = 26 )
    @Length(max=200, message = "主题词不能大于200")
    private String projKeywords;
    /** 主题词(英文) */
    @ApiModelProperty(value = "主题词(英文)", position = 26 )
    @Length(max=200, message = "主题词(英文)不能大于200")
    private String keywordsEnglish;
    /** 主要研究内容和意义 */
    @ApiModelProperty(value = "主要研究内容和意义", position = 13 )
    @Length(max=2000, message = "主要研究内容和意义不能大于2000")
    private String projContent;
    /** 参考文献 */
    @ApiModelProperty(value = "参考文献", position = 14)
    @Length(max=5000, message = "参考文献不能大于5000")
    private String projReference;
    /** 立项依据 */
    @ApiModelProperty(value = "立项依据", position = 27 )
    @Length(max=2147483647, message = "立项依据不能大于2147483647")
    private String projBasis;
    /** 研究内容和研究目标，拟解决的关键问题 */
    @ApiModelProperty(value = "研究内容和研究目标，拟解决的关键问题", position = 28 )
    @Length(max=2147483647, message = "研究内容和研究目标，拟解决的关键问题不能大于2147483647")
    private String researchContent;
    /** 研究思路、方法、技术路线、实验方案及可行性分析 */
    @ApiModelProperty(value = "研究思路、方法、技术路线、实验方案及可行性分析", position = 29 )
    @Length(max=2147483647, message = "研究思路、方法、技术路线、实验方案及可行性分析不能大于2147483647")
    private String researchPlan;
    /** 项目的特色和创新之处 */
    @ApiModelProperty(value = "项目的特色和创新之处", position = 31 )
    @Length(max=2147483647, message = "项目的特色和创新之处不能大于2147483647")
    private String mainFeatures;
    /** 研究进度计划 */
    @ApiModelProperty(value = "研究进度计划", position = 30 )
    @Length(max=2147483647, message = "研究进度计划不能大于2147483647")
    private String studyPlan;
    /** 预期研究成果 */
    @ApiModelProperty(value = "预期研究成果", position = 32 )
    @Length(max=2147483647, message = "预期研究成果不能大于2147483647")
    private String expectedResults;
    /** 研究工作积累和已取得的研究工作成绩 */
    @ApiModelProperty(value = "研究工作积累和已取得的研究工作成绩", position = 33 )
    @Length(max=2147483647, message = "研究工作积累和已取得的研究工作成绩不能大于2147483647")
    private String workFoundation;
    /** 实验条件和资料 */
    @ApiModelProperty(value = "实验条件和资料", position = 34 )
    @Length(max=2147483647, message = "实验条件和资料不能大于2147483647")
    private String workingConditions;
    /** 申请者和项目组主要成员研究工作简历 */
    @ApiModelProperty(value = "申请者和项目组主要成员研究工作简历", position = 35 )
    @Length(max=2147483647, message = "申请者和项目组主要成员研究工作简历不能大于2147483647")
    private String memResume;
    /** 申请者正在承担的其它研究项目 */
    @ApiModelProperty(value = "申请者正在承担的其它研究项目", position = 14 )
    @Length(max=1000, message = "申请者正在承担的其它研究项目1000")
    private String researchProjects;
    /** 投资总额 */
    @ApiModelProperty(value = "投资总额", position = 39)
    private BigDecimal totalFunding;
    /** 卫生健康委资助 */
    @ApiModelProperty(value = "卫生健康委资助", position = 40)
    private BigDecimal govFunding;
    /** 单位配套 */
    @ApiModelProperty(value = "单位配套", position = 41)
    private BigDecimal unitFunding;
    /** 自筹 */
    @ApiModelProperty(value = "自筹", position = 42)
    private BigDecimal selfFunding;
    /** 其他 */
    @ApiModelProperty(value = "其他", position = 43)
    private BigDecimal otherFunding;
    @ApiModelProperty(value = "报告正文", position = 36 )
    @Length(max=2147483647, message = "报告正文不能大于2147483647")
    private String projDoc;
    /** 否选择接受立项不资助 */
    @ApiModelProperty(value = "是否选择接受立项不资助", position = 1 )
    @Length(max=4, message = "是否选择接受立项不资助不能大于4")
    private String isAccept;
    /** 是否存在境外机构或人员参与 */
    @ApiModelProperty(value = "是否存在境外机构或人员参与", position = 1 )
    @Length(max=4, message = "是否存在境外机构或人员参与不能大于4")
    private String isOverseas;
    /** 是否可实现成果转化或临床应用 */
    @ApiModelProperty(value = "是否可实现成果转化或临床应用", position = 1)
    @Length(max=4, message = "是否可实现成果转化或临床应用不能大于4")
    private String isAchieve;
    /** （存在境外机构或人员）备注 */
    @ApiModelProperty(value = "（存在境外机构或人员）备注", position = 1 )
    @Length(max=400, message = "（存在境外机构或人员）备注不能大于400")
    private String overseasRemark;
    /** 备注 */
    @ApiModelProperty(value = "备注", position = 38 )
    @Length(max=65535, message = "备注不能大于65535")
    private String remark;
}